4. formel — Jscatter 1.2.0 documentation

# 4. formel

## 4.1. Functions

`loglist` |
`gauss` |
`lorentz` |
`voigt` |
`lognorm` |
`box` |
`Ea` |
`boseDistribution` |

## 4.2. Quadrature

`parQuadratureSimpson` |
`parQuadratureFixedGauss` |
`parQuadratureAdaptiveGauss` |
`parDistributedAverage` |
`multiParDistributedAverage` |
`sphereAverage` |
`psphereAverage` |
`convolve` |

## 4.3. Centrifugation

`sedimentationCoefficient` |
`sedimentationProfile` |
`sedimentationProfileFaxen` |

## 4.4. NMR

`DrotfromT12` |
`T1overT2` |

## 4.5. Material Data

`scatteringLengthDensityCalc` |
`waterdensity` |
`bufferviscosity` |
`dielectricConstant` |
`watercompressibility` |
`cstar` |
`molarity` |
`viscosity` |
`Dtrans` |
`Drot` |

## 4.6. other Stuff

`memoize` |
`xyz2rphitheta` |
`rphitheta2xyz` |
`rotationMatrix` |
`fibonacciLatticePointsOnSphere` |
`randomPointsOnSphere` |
`randomPointsInCube` |
`smooth` |

## 4.7. Constants and Tables

`felectron` |
`Elements` |